HelperFunctions class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getResizedImage(
String? imagePath) → Future< Uint8List?> -
pickImage(
) → Future< XFile?> -
showMessage(
BuildContext context, String? message, Color color, {int? seconds}) → void -
showTopMessage(
BuildContext context, String message, {Duration? duration}) → void -
translateMenuTitle(
CoreLocalizations localizations, String key) → String