BlocMessageKeys class abstract
Base class for creating message key constants to avoid magic strings
Usage:
class UserBlocMessageKeys {
static const String updateSuccess = 'userUpdateSuccess';
static const String updateFailure = 'userUpdateFailure';
static const String deleteSuccess = 'userDeleteSuccess';
static const String deleteFailure = 'userDeleteFailure';
}
Constructors
- BlocMessageKeys()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited