getStartupCredentials function
Returns the credentials supplied by the web startup page, or null when
none were supplied (always null on non-web platforms). The values are
cleared from sessionStorage after being read so they are consumed once.
Implementation
StartupCredentials? getStartupCredentials() => readStartupCredentials();