CoreLocalizations class abstract
Callers can lookup localized strings with an instance of CoreLocalizations
returned by CoreLocalizations.of(context).
Applications need to include CoreLocalizations.delegate() in their app's
localizationDelegates list, and the locales they support in the app's
supportedLocales list. For example:
import 'generated/core_localizations.dart';
return MaterialApp(
localizationsDelegates: CoreLocalizations.localizationsDelegates,
supportedLocales: CoreLocalizations.supportedLocales,
home: MyApplicationHome(),
);
Update pubspec.yaml
Please make sure to update your pubspec.yaml to include the following packages:
dependencies:
# Internationalization support.
flutter_localizations:
sdk: flutter
intl: any # Use the pinned version from flutter_localizations
# Rest of dependencies
iOS Applications
iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.
First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.
Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.
Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the CoreLocalizations.supportedLocales property.
Constructors
- CoreLocalizations(String locale)
Properties
- about → String
-
About menu item
no setter
- aboutGrowERP → String
-
About GrowERP menu item
no setter
- accounting → String
-
Accounting menu item
no setter
- accountingDashboard → String
-
Accounting dashboard menu item
no setter
- accountingLedger → String
-
Accounting ledger menu item
no setter
- accountingPurch → String
-
Accounting purchase menu item
no setter
- accountingSales → String
-
Accounting sales menu item
no setter
- accounts → String
-
Accounts menu item or section header
no setter
- addNew → String
-
Add new item button text
no setter
- addPartner → String
-
Button text to add chat partner
no setter
- administrators → String
-
Administrators label
no setter
- allMessagesRead → String
-
Status message when all messages are read
no setter
- allOpportunities → String
-
All opportunities label
no setter
- andAtLeastOne → String
-
Partial validation message indicating minimum requirement
no setter
- applications → String
-
Applications menu item
no setter
- assets → String
-
Assets menu item
no setter
- authLoginFailure → String
-
BLoC message: Login failed
no setter
- authLoginSuccess → String
-
BLoC message: Login successful
no setter
- authLogoutSuccess → String
-
BLoC message: Logout successful
no setter
- authPasswordResetFailure → String
-
BLoC message: Password reset failed
no setter
- authPasswordResetSuccess → String
-
BLoC message: Password reset successful
no setter
- authRegisterFailure → String
-
BLoC message: Registration failed
no setter
- authRegisterSuccess → String
-
BLoC message: Registration successful. You can now login with the password sent by email
no setter
- authUpdateFailure → String
-
BLoC message: Failed to update authentication
no setter
- authUpdateSuccess → String
-
BLoC message: Authentication updated successfully
no setter
- backendServer → String
-
Backend server input label
no setter
- balanceSheet → String
-
Balance sheet report menu item
no setter
- balanceSummary → String
-
Balance summary report menu item
no setter
- businessCompanyName → String
-
Business name validation error message
no setter
- businessNameError → String
-
Business name validation error message
no setter
- cancel → String
-
Cancel button text
no setter
- cannotLoadRestRequests → String
-
Error message when REST requests fail to load
no setter
- catalog → String
-
Catalog menu item
no setter
- categories → String
-
Categories menu item
no setter
- chat → String
-
Chat menu item
no setter
- chatAddNew → String
-
Add new item button text
no setter
- chatCreate → String
-
Create button text
no setter
- chatFieldRequired → String
-
Generic required field error message
no setter
- chatMessageDeleteFailure → String
-
BLoC message: Failed to delete message
no setter
- chatMessageDeleteSuccess → String
-
BLoC message: Message deleted successfully
no setter
- chatMessageFetchFailure → String
-
BLoC message: Failed to fetch messages
no setter
- chatMessageSendFailure → String
-
BLoC message: Failed to send message
no setter
- chatMessageSendSuccess → String
-
BLoC message: Message sent successfully
no setter
- chatNo → String
-
Partial text for 'no items found' messages
no setter
- chatNotActive → String
-
Error message when chat is not active
no setter
- chatPartner → String
-
Label for chat partner field
no setter
- chatRoom → String
-
Chat room label or header
no setter
- chatRoomAddFailure → String
-
BLoC message: Failed to add chat room
no setter
- chatRoomAddSuccess → String
-
BLoC message: Chat room added successfully
no setter
- chatRoomDeleteFailure → String
-
BLoC message: Failed to delete chat room
no setter
- chatRoomDeleteSuccess → String
-
BLoC message: Chat room deleted successfully
no setter
- chatRoomFetchFailure → String
-
BLoC message: Failed to fetch chat rooms
no setter
- chatRoomHeader → String
-
Chat header with number symbol
no setter
- chatRoomUpdateFailure → String
-
BLoC message: Failed to update chat room
no setter
- chatRoomUpdateSuccess → String
-
BLoC message: Chat room updated successfully
no setter
- chatServer → String
-
Chat server input label
no setter
- chatUpdate → String
-
Update button text
no setter
- chatUsersAndGroups → String
-
Section header for chat users and groups
no setter
- checkIn → String
-
Check in menu item
no setter
- checkOut → String
-
Check out menu item
no setter
- clients → String
-
Clients menu item
no setter
- colorScheme → String
-
Color scheme picker dialog title
no setter
- company → String
-
Company menu item
no setter
- companyPartyId → String
-
Company party ID input label
no setter
- completeRegistration → String
-
Complete registration dialog title
no setter
- continueButton → String
-
Continue button text
no setter
- contributing → String
-
Contributing menu item
no setter
- create → String
-
Create button text
no setter
- createPassword → String
-
Create password dialog title
no setter
- creditCardDetails → String
-
Credit card details hint text
no setter
- creditCardInfo → String
-
Credit card info label
no setter
- crm → String
-
CRM menu item
no setter
- currency → String
-
Currency input label
no setter
- currencyError → String
-
Currency validation error message
no setter
- customer → String
-
Label for customer
no setter
- customers → String
-
Customers menu item
no setter
- cvvCode → String
-
CVV code input label
no setter
- cvvHint → String
-
CVV code input hint
no setter
- dateTime → String
-
Date and time label
no setter
- deleteWarning → String
-
Delete warning dialog title
no setter
- deleteYourself → String
-
Delete yourself button text
no setter
- deleteYourselfAndCompany → String
-
Delete yourself and company button text
no setter
- demoData → String
-
Demo data checkbox label
no setter
- email → String
-
Email input label
no setter
- emailAddress → String
-
Email address input label
no setter
- emailAddressError → String
-
Email address validation error message
no setter
- emailAddressError2 → String
-
Email address format validation error message
no setter
- employees → String
-
Employees menu item
no setter
- enterBackendUrl → String
-
Enter backend URL dialog title
no setter
- enterCompanyAndCurrency → String
-
Company and currency input instruction
no setter
- enterCompanyName → String
-
Company name input instruction
no setter
- error → String
-
Error status text
no setter
- errorMessage → String
-
Error message label
no setter
- evaluationPeriodDetails → String
-
Detailed evaluation period explanation
no setter
- expiryDate → String
-
Expiry date input label
no setter
- expiryDateHint → String
-
Expiry date input hint
no setter
- fieldRequired → String
-
Field required validation error message
no setter
- firstName → String
-
First name input label
no setter
- firstNameError → String
-
First name validation error message
no setter
- forgotPassword → String
-
Forgot password link text
no setter
- generateDemoData → String
-
Generate demo data checkbox text
no setter
- goHome → String
-
Go home button tooltip
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- incomingInvoices → String
-
Incoming invoices menu item
no setter
- incomingPayments → String
-
Incoming payments menu item
no setter
- incomingShipments → String
-
Incoming shipments menu item
no setter
- inOut → String
-
In/out menu item
no setter
- inventory → String
-
Inventory menu item
no setter
- invoice → String
-
Label for invoice
no setter
- itemIsRequired → String
-
Validation message indicating a required item
no setter
- itemTypes → String
-
Item types menu item or section header
no setter
- journal → String
-
Journal menu item or section header
no setter
- lastName → String
-
Last name input label
no setter
- lastNameError → String
-
Last name validation error message
no setter
- leads → String
-
Leads menu item
no setter
- ledgerAccnt → String
-
Ledger account menu item
no setter
- ledgerJournals → String
-
Ledger journals menu item
no setter
- ledgerTransaction → String
-
Ledger transaction menu item
no setter
- ledgerTree → String
-
Ledger tree menu item
no setter
- localeName → String
-
final
- login → String
-
Login button text
no setter
- loginName → String
-
Login name label
no setter
- loginWithExistingUserName → String
-
Login form header text for existing users
no setter
- logout → String
-
Logout button text
no setter
- main → String
-
Main menu item
no setter
- mainDashboard → String
-
Main dashboard menu item or navigation link
no setter
- messageText → String
-
Placeholder text for message input field
no setter
- ms → String
-
Milliseconds abbreviation
no setter
- myHotel → String
-
My hotel menu item
no setter
- myOpportunities → String
-
My opportunities menu item
no setter
- myTodoTasks → String
-
My todo tasks menu item
no setter
- name → String
-
Name field label
no setter
- nameOnCard → String
-
Name on card input label
no setter
- newChat → String
-
Button text for creating new chat
no setter
- no → String
-
No answer text
no setter
- noAccess → String
-
No access error message
no setter
- noAccessHere → String
-
No access here error message
no setter
- noRestRequests → String
-
No REST requests message
no setter
- notAvailable → String
-
Not available placeholder text
no setter
- notificationFetchFailure → String
-
BLoC message: Failed to fetch notifications
no setter
- notificationFetchSuccess → String
-
BLoC message: Notifications fetched successfully
no setter
- notificationMarkReadFailure → String
-
BLoC message: Failed to mark notification as read
no setter
- notificationMarkReadSuccess → String
-
BLoC message: Notification marked as read
no setter
- nroMembers → String
-
Abbreviation for number of members
no setter
- number → String
-
Number input label
no setter
- numberHint → String
-
Card number input hint
no setter
- ok → String
-
OK button text
no setter
- onlyUserDelete → String
-
Only delete user option text
no setter
- openInvoices → String
-
Label for open invoices dashboard item
no setter
- openSourceLicenses → String
-
Open source licenses menu item
no setter
- opportunities → String
-
Opportunities menu item
no setter
- order → String
-
Label for order
no setter
- orders → String
-
Orders menu item
no setter
- organization → String
-
Organization menu item
no setter
- otherEmployees → String
-
Other employees label
no setter
- outgoingInvoices → String
-
Outgoing invoices menu item
no setter
- outgoingPayments → String
-
Outgoing payments menu item
no setter
- outgoingShipments → String
-
Outgoing shipments menu item
no setter
- parameters → String
-
Parameters label
no setter
- password → String
-
Password input label
no setter
- passwordError → String
-
Password validation error message
no setter
- passwordError2 → String
-
Password validation error message variant
no setter
- passwordHelper → String
-
Password helper text
no setter
- passwordMismatch → String
-
Password mismatch validation error
no setter
- passwordValidationError → String
-
Password validation error message
no setter
- payment → String
-
Label for payment
no setter
- paymentPlan → String
-
Payment plan input label
no setter
- paymentTypes → String
-
Payment types menu item or section header
no setter
- paymtTypes → String
-
Payment types menu item
no setter
- payNow → String
-
Pay now button text
no setter
- planSelection → String
-
Plan selection menu item
no setter
- privacyCodeOfConduct → String
-
Privacy and code of conduct menu item
no setter
- products → String
-
Products menu item
no setter
- purchaseOrders → String
-
Purchase orders menu item
no setter
- purchaseUnpaidInvoices → String
-
Purchase unpaid invoices label
no setter
- pvt → String
-
Abbreviation for Private
no setter
- referrerUrl → String
-
Referrer URL label
no setter
- refresh → String
-
Refresh button text
no setter
- register → String
-
Register button text
no setter
- registerNewCompanyAndAdmin → String
-
Register new company link text
no setter
- registration → String
-
Registration dialog title
no setter
- reports → String
-
Reports menu item
no setter
- requestName → String
-
Request name label
no setter
- requests → String
-
Requests menu item
no setter
- requestUrl → String
-
Request URL label
no setter
- reservations → String
-
Reservations menu item
no setter
- restart → String
-
Restart button text
no setter
- restRequestDetails → String
-
REST request details title
no setter
- restRequests → String
-
REST requests menu item
no setter
- revenueExpense → String
-
Revenue and expense report menu item
no setter
- room → String
-
Label for room
no setter
- rooms → String
-
Rooms menu item
no setter
- roomTypes → String
-
Room types menu item
no setter
- runningTime → String
-
Running time label
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesOpenInvoices → String
-
Sales open invoices label
no setter
- salesOrders → String
-
Sales orders menu item
no setter
- search → String
-
Search button text
no setter
- searchInName → String
-
Placeholder text for name search field
no setter
- selectChatPartner → String
-
Instruction to select a chat partner
no setter
- selectLanguage → String
-
Select language instruction
no setter
- selectPlanError → String
-
Select plan validation error message
no setter
- send → String
-
Send button text
no setter
- sendNewPassword → String
-
Send new password dialog title
no setter
- serverHost → String
-
Server host label
no setter
- serverIp → String
-
Server IP label
no setter
- setUp → String
-
Set up menu item
no setter
- sFound → String
-
Partial text for 'items found' messages
no setter
- shipment → String
-
Label for shipment
no setter
- slowHit → String
-
Slow hit label
no setter
- staff → String
-
Staff menu item
no setter
- startEvaluation → String
-
Button to start evaluation period
no setter
- status → String
-
Status label
no setter
- submitNewPassword → String
-
Submit new password button text
no setter
- subscription → String
-
Subscription dialog title
no setter
- subscriptionExpired → String
-
Message shown when subscription has expired
no setter
- subscriptions → String
-
Subscriptions menu item
no setter
- success → String
-
Success status text
no setter
- supplier → String
-
Label for supplier
no setter
- suppliers → String
-
Suppliers menu item
no setter
- tasks → String
-
Tasks menu item
no setter
- tempPassword → String
-
Temporary password information text
no setter
- test → String
-
Test menu item
no setter
- testSystem → String
-
Test system text
no setter
- theme → String
-
Theme menu item
no setter
- timePeriods → String
-
Time periods menu item or section header
no setter
- transaction → String
-
Label for transaction
no setter
- transactions → String
-
Transactions menu item or section header
no setter
- trialPeriod → String
-
Trial period text
no setter
- unknown → String
-
Placeholder text for unknown values
no setter
- unreadMessages → String
-
Label for unread messages count
no setter
- update → String
-
Update button text
no setter
- user → String
-
User label
no setter
- userAndCompanyDelete → String
-
Delete user and company option text
no setter
- usernameEmail → String
-
Username or email input label
no setter
- usernameEmailError → String
-
Username/email validation error message
no setter
- userRequestStatus → String
-
REST request list column header for user/request/status
no setter
- verifyPassword → String
-
Verify password input label
no setter
- verifyPasswordError → String
-
Verify password validation error message
no setter
- verifyPasswordHelper → String
-
Verify password helper text
no setter
- viewLicense → String
-
View license menu item
no setter
- viewReadme → String
-
View readme menu item
no setter
- website → String
-
Website menu item
no setter
- welcome → String
-
Welcome message
no setter
- welcomeTitle → String
-
Welcome page title for evaluation period
no setter
- welcomeToGrowERPBusinessSystem → String
-
Welcome message on home page
no setter
- whLocations → String
-
Warehouse locations menu item
no setter
- yes → String
-
Yes answer text
no setter
Methods
-
aboutApp(
String appName) → String - About app dialog title
-
copyright(
String year) → String - Copyright text with year
-
currentPaymentMethod(
String method) → String - Current payment method display text
-
evaluationPeriodMessage(
int days) → String - Evaluation period information message
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
passwordChangeSuccess(
String username) → String - BLoC message: Password changed successfully
-
toString(
) → String -
A string representation of this object.
inherited
-
username(
String username) → String - Username display text
-
version(
String version, String build) → String - Version display text
-
welcomeMessage(
String name) → String - Personalized welcome message
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → CoreLocalizations?
Constants
-
delegate
→ const LocalizationsDelegate<
CoreLocalizations> -
localizationsDelegates
→ const List<
LocalizationsDelegate> - A list of this localizations delegate along with the default localizations delegates.
-
supportedLocales
→ const List<
Locale> - A list of this localizations delegate's supported locales.